"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const PlaywrightController_1 = require("./PlaywrightController");
const PuppeteerController_1 = require("./PuppeteerController");
class BrowserControllerFactory {
    /**
     * Returns instance of BrowserController corresponding to provided page
     */
    static createForPage(page) {
        if (this.isPlaywrightPage(page)) {
            return new PlaywrightController_1.PlaywrightController(page);
        }
        else if (this.isPuppeteerPage(page)) {
            return new PuppeteerController_1.PuppeteerController(page);
        }
        else {
            throw new Error('Expected instance of Puppeteer or Playwright Page. Got: ' +
                page);
        }
    }
    static isPlaywrightPage(page) {
        return typeof page['route'] === 'function';
    }
    static isPuppeteerPage(page) {
        return typeof page['setRequestInterception'] === 'function';
    }
}
exports.BrowserControllerFactory = BrowserControllerFactory;
//# sourceMappingURL=BrowserControllerFactory.js.map