"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const url_1 = require("url");
const utils_1 = require("../utils");
class PuppeteerController {
    constructor(page) {
        this.page = page;
    }
    async startInterception(onRequest) {
        await this.page.setRequestInterception(true);
        this.page.on('request', (request) => {
            onRequest(this.toBrowserRequest(request), (response) => request.respond(response), () => request.continue());
        });
    }
    toBrowserRequest(request) {
        // TODO find a better alternative for url.parse
        const { pathname, query, protocol, host } = url_1.parse(request.url(), true);
        return {
            type: request.resourceType(),
            url: request.url(),
            body: utils_1.tryJsonParse(request.postData()),
            method: request.method(),
            headers: request.headers() || {},
            path: pathname !== null && pathname !== void 0 ? pathname : '',
            hostname: `${protocol}//${host}`,
            query: query,
            sourceOrigin: this.getRequestOrigin(request),
        };
    }
    /**
     * Obtain request origin url from originating frame url
     */
    getRequestOrigin(request) {
        var _a;
        return utils_1.getOrigin((_a = request.frame()) === null || _a === void 0 ? void 0 : _a.url());
    }
}
exports.PuppeteerController = PuppeteerController;
//# sourceMappingURL=PuppeteerController.js.map